@@ -21,6 +21,7 @@ PlaylistItem::PlaylistItem(PlaylistItem *playlist, QObject *parent) :
     m_duration(playlist->duration()),
     m_date(playlist->date()),
     m_thumbnailUrl(playlist->thumbnailUrl()),
+    m_largeThumbnailUrl(playlist->largeThumbnailUrl()),
     m_videoCount(playlist->videoCount()),
     m_service(playlist->service())
 {
@@ -37,6 +38,7 @@ void PlaylistItem::loadPlaylist(PlaylistItem *playlist) {
     this->setDuration(playlist->duration());
     this->setDate(playlist->date());
     this->setThumbnailUrl(playlist->thumbnailUrl());
+    this->setLargeThumbnailUrl(playlist->largeThumbnailUrl());
     this->setVideoCount(playlist->videoCount());
     this->setService(playlist->service());
 }
@@ -67,6 +69,7 @@ void PlaylistItem::loadYouTubePlaylist(const QDomNode &playlist) {
     this->setDescription(playlist.firstChildElement("summary").text());
     this->setDate(Utils::localDateTimeFromString(playlist.firstChildElement("published").text()));
     this->setThumbnailUrl(QUrl(playlist.firstChildElement("media:group").firstChildElement("media:thumbnail").attribute("url")));
+    this->setLargeThumbnailUrl(QUrl(this->thumbnailUrl().toString().section('/', 0, -2).append("/hqdefault.jpg")));
     this->setVideoCount(playlist.firstChildElement("yt:countHint").text().toInt());
     this->setService(Services::YouTube);
 }
@@ -82,7 +85,8 @@ void PlaylistItem::loadVimeoAlbum(const QDomElement &album) {
 
     QDomNodeList thumbnails = album.firstChildElement("thumbnail_video").firstChildElement("thumbnails").childNodes();
 
-    if (thumbnails.size() > 1) {
+    if (thumbnails.size() > 2) {
         this->setThumbnailUrl(QUrl(thumbnails.at(1).toElement().text()));
+        this->setLargeThumbnailUrl(QUrl(thumbnails.at(2).toElement().text()));
     }
 }
