@@ -239,6 +239,12 @@ class Settings : public QSettings
     Q_PROPERTY(bool cuteTubePlayerEnabled
                READ cuteTubePlayerEnabled
                CONSTANT)
+#ifdef GRABBER_PLUGIN
+    Q_PROPERTY(bool updatePluginOnStartup
+               READ updatePluginOnStartup
+               WRITE setUpdatePluginOnStartup
+               NOTIFY updatePluginOnStartupChanged)
+#endif
 
 public:
     explicit Settings(QObject *parent = 0);
@@ -310,6 +316,9 @@ public:
     bool eventFeedInstalled() const;
 #endif
     inline bool cuteTubePlayerEnabled() const { return m_cuteTubePlayerEnabled; }
+#ifdef GRABBER_PLUGIN
+    inline bool updatePluginOnStartup() const { return m_updatePlugin; }
+#endif
 
     static Settings* instance();
 
@@ -377,6 +386,9 @@ public slots:
 #ifdef Q_WS_MAEMO_5
     void setEventFeedEnabled(bool enabled);
 #endif
+#ifdef GRABBER_PLUGIN
+    void setUpdatePluginOnStartup(bool update);
+#endif
 
 private:
     void setYouTubePlaybackFormats(QVariantList formats);
@@ -457,7 +469,12 @@ signals:
     void networkProxyPortChanged(quint16 port);
     void networkProxyUserChanged(const QString &user);
     void networkProxyPasswordChanged(const QString &password);
+#ifdef Q_WS_MAEMO_5
     void eventFeedEnabledChanged(bool enabled);
+#endif
+#ifdef GRABBER_PLUGIN
+    void updatePluginOnStartupChanged(bool update);
+#endif
 
 private:
     QSet<int> m_youtubePlaybackFormats;
@@ -509,6 +526,9 @@ private:
     bool m_eventFeedInstalled;
 #endif
     bool m_cuteTubePlayerEnabled;
+#ifdef GRABBER_PLUGIN
+    bool m_updatePlugin;
+#endif
 };
 
 #endif // SETTINGS_H
