@@ -553,7 +553,7 @@ void Sharing::checkTwitterVideos() {
                             youtubeIds.append(url.section(QRegExp("v=|/"), -1).section(QRegExp("&|\\?"), 0, 0));
                         }
                         else if (url.contains(DAILYMOTION_SHARING_RE)) {
-                            dailymotionIds.append(url.section('/', -1).left(6));
+                            dailymotionIds.append(url.section('/', -1).section('_', 0, 0));
                         }
                         else if (url.contains(VIMEO_SHARING_RE)) {
                             vimeoIds.append(url.section('/', -1));
