@@ -473,82 +473,6 @@ void UrlGrabber::getVimeoVideoUrl(const QString &id) {
 }
 
 void UrlGrabber::parseVimeoVideoPage() {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
-
-    if (!reply) {
-        this->setBusy(false);
-        emit error(tr("Network error"));
-        return;
-    }
-
-    if (this->cancelled()) {
-        return;
-    }
-
-    QString response(reply->readAll());
-    QString params = response.section("config:", 1, 1).section("};", 0, 0);
-    QVariantMap paramMap = Json::parse(params).toMap();
-
-    if (paramMap.isEmpty()) {
-        qDebug() << response;
-        this->setBusy(false);
-        emit error(tr("Unable to retrieve video. Access may be restricted"));
-    }
-    else {
-        QVariantMap requestMap = paramMap.value("request").toMap();
-        QVariantMap videoMap = paramMap.value("video").toMap();
-        QVariantMap formatMap = videoMap.value("files").toMap();
-        QString codec("h264");
-        QString quality;
-
-        if (!formatMap.isEmpty()) {
-            codec = formatMap.keys().first();
-
-            QVariantList qualities = formatMap.value(codec).toList();
-            int i = 0;
-
-            while ((quality.isEmpty()) && (i < m_vimeoFormats.size())) {
-                if (qualities.contains(m_vimeoFormats.at(i).value)) {
-                    quality = m_vimeoFormats.at(i).value.toString();
-                    m_format = m_vimeoFormats.at(i).format;
-                }
-
-                i++;
-            }
-
-            QString timeStamp = requestMap.value("timestamp").toString();
-            QString signature = requestMap.value("signature").toString();
-            QString id = videoMap.value("id").toString();
-            QUrl url("http://player.vimeo.com/play_redirect");
-            url.addQueryItem("quality", quality);
-            url.addQueryItem("clip_id", id);
-            url.addQueryItem("time", timeStamp);
-            url.addQueryItem("sig", signature);
-
-            if (quality != "mobile") {
-                url.addQueryItem("codecs", codec);
-            }
-
-            this->getVimeoVideoRedirect(url);
-        }
-        else {
-            this->setBusy(false);
-            qDebug() << response;
-            emit error(tr("Unable to retrieve video. Access may be restricted"));
-        }
-    }
-
-    reply->deleteLater();
-}
-
-void UrlGrabber::getVimeoVideoRedirect(const QUrl &url) {
-    QNetworkRequest request(url);
-    QNetworkReply *reply = this->networkAccessManager()->get(request);
-    this->connect(reply, SIGNAL(finished()), this, SLOT(checkVimeoVideoRedirect()));
-    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
-}
-
-void UrlGrabber::checkVimeoVideoRedirect() {
     this->setBusy(false);
     QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
 
@@ -561,13 +485,31 @@ void UrlGrabber::checkVimeoVideoRedirect() {
         return;
     }
 
-    QUrl redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
+    QString response(reply->readAll());
+    QString params = response.section("\"h264\":", 1, 1).section(",\"hls\":", 0, 0);
+    QVariantMap formatMap = Json::parse(params).toMap();
 
-    if (redirect.isEmpty()) {
-        emit gotVideoUrl(reply->request().url(), m_format);
+    if (formatMap.isEmpty()) {
+        qDebug() << response;
+        emit error(tr("Unable to retrieve video. Access may be restricted"));
     }
     else {
-        emit gotVideoUrl(redirect, m_format);
+        QUrl url;
+        int i = 0;
+
+        while ((url.isEmpty()) && (i  < m_vimeoFormats.size())) {
+            url.setUrl(formatMap.value(m_vimeoFormats.at(i).value.toString(), "").toMap().value("url").toString());
+            m_format = m_vimeoFormats.at(i).format;
+            i++;
+        }
+
+        if (url.isEmpty()) {
+            qDebug() << response;
+            emit error(tr("Unable to retrieve video. Access may be restricted"));
+        }
+        else {
+            emit gotVideoUrl(url, m_format);
+        }
     }
 
     reply->deleteLater();
@@ -773,26 +715,29 @@ void UrlGrabber::checkDailymotionVideoFormats() {
     QString response(reply->readAll());
     QVariantMap info = Json::parse(response.section("var info = ", 1, 1).section(";\n", 0, 0)).toMap();
     QVariantList formats;
-    int i = 0;
 
-    QMap<QString, QString> formatNames;
-    formatNames["stream_h264_url"] = QString("%1 AVC1").arg(tr("Normal"));
-    formatNames["stream_h264_hq_url"] = "480P AVC1";
-    formatNames["stream_h264_hd_url"] = "720P AVC1";
-    formatNames["stream_h264_hd1080_url"] = "1080P AVC1";
+    QStringList keys;
+    keys << "stream_h264_hd1080_url"
+         << "stream_h264_hd_url"
+         << "stream_h264_hq_url"
+         << "stream_h264_url";
 
-    foreach (QString formatName, formatNames.keys()) {
-        QUrl url = info.value(formatName).toUrl();
+    QStringList names;
+    names << "1080P AVC1"
+          << "720 AVC1"
+          << "480P AVC1"
+          << QString("%1 AVC1").arg(tr("Normal"));
+
+    for (int i = 0; i < keys.size(); i++){
+        QUrl url = info.value(keys.at(i)).toUrl();
 
         if (!url.isEmpty()) {
             QVariantMap format;
-            format["name"] = formatNames.value(formatName);
+            format["name"] = names.at(i);
             format["service"] = Services::Dailymotion;
             format["url"] = url;
             formats << format;
         }
-
-        i++;
     }
 
     if (formats.isEmpty()) {
@@ -830,58 +775,38 @@ void UrlGrabber::checkVimeoVideoFormats() {
     }
 
     QString response(reply->readAll());
-    QString params = response.section("config:", 1, 1).section("};", 0, 0);
-    QVariantMap paramMap = Json::parse(params).toMap();
+    QString params = response.section("\"h264\":", 1, 1).section(",\"hls\":", 0, 0);
+    QVariantMap formatMap = Json::parse(params).toMap();
+    QVariantList formats;
 
-    if (paramMap.isEmpty()) {
+    QStringList keys;
+    keys << "hd"
+         << "sd"
+         << "mobile";
+
+    QStringList names;
+    names << "720 AVC1"
+          << "360P AVC1"
+          << tr("Mobile");
+
+    for (int i = 0; i < keys.size(); i++){
+        QUrl url = formatMap.value(keys.at(i)).toMap().value("url").toUrl();
+
+        if (!url.isEmpty()) {
+            QVariantMap format;
+            format["name"] = names.at(i);
+            format["service"] = Services::Vimeo;
+            format["url"] = url;
+            formats << format;
+        }
+    }
+
+    if (formats.isEmpty()) {
         qDebug() << response;
-        emit error(tr("Unable to retrieve video. Access may be restricted"));
+        emit error(tr("Unable to retrieve video formats. Access may be restricted"));
     }
     else {
-        QVariantMap requestMap = paramMap.value("request").toMap();
-        QVariantMap videoMap = paramMap.value("video").toMap();
-        QVariantMap formatMap = videoMap.value("files").toMap();
-        QString codec("h264");
-
-        if (!formatMap.isEmpty()) {
-            codec = formatMap.keys().first();
-
-            QStringList qualities = formatMap.value(codec).toStringList();
-            QVariantList formats;
-            QMap<QString, QString> formatNames;
-            formatNames["mobile"] = tr("Mobile");
-            formatNames["sd"] = "360P AVC1";
-            formatNames["hd"] = "720P AVC1";
-
-            while (!qualities.isEmpty()) {
-                QString quality = qualities.takeFirst();
-                QString timeStamp = requestMap.value("timestamp").toString();
-                QString signature = requestMap.value("signature").toString();
-                QString id = videoMap.value("id").toString();
-
-                QVariantMap format;
-                format["name"] = formatNames[quality];
-                format["service"] = Services::Vimeo;
-                QUrl url("http://player.vimeo.com/play_redirect");
-                url.addQueryItem("quality", quality);
-                url.addQueryItem("clip_id", id);
-                url.addQueryItem("time", timeStamp);
-                url.addQueryItem("sig", signature);
-
-                if (quality != "mobile") {
-                    url.addQueryItem("codecs", codec);
-                }
-
-                format["url"] = url;
-                formats << format;
-            }
-
-            emit gotVideoFormats(formats);
-        }
-        else {
-            qDebug() << response;
-            emit error(tr("Unable to retrieve video formats. Access may be restricted"));
-        }
+        emit gotVideoFormats(formats);
     }
 
     reply->deleteLater();
