@@ -12,6 +12,7 @@
 #include <QLabel>
 #include <QVBoxLayout>
 #include <QMenuBar>
+#include <QMaemo5Style>
 
 ArchiveWindow::ArchiveWindow( StackedWindow *parent) :
     StackedWindow(parent),
@@ -20,7 +21,7 @@ ArchiveWindow::ArchiveWindow( StackedWindow *parent) :
     m_filterBox(new FilterBox(this)),
     m_contextMenu(new QMenu(this)),
     m_deleteAction(m_contextMenu->addAction(tr("Delete"), this, SLOT(showConfirmDeleteDialog()))),
-    m_noResultsLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No videos found")), this)),
+    m_noResultsLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No videos found")), this)),
     m_vbox(0)
 {
     this->setWindowTitle(tr("Archive"));
