@@ -11,6 +11,7 @@
 #include <QMenu>
 #include <QAction>
 #include <QGridLayout>
+#include <QMaemo5Style>
 
 VimeoUserAlbumListTab::VimeoUserAlbumListTab(QWidget *parent) :
     AbstractTab(parent),
@@ -19,7 +20,7 @@ VimeoUserAlbumListTab::VimeoUserAlbumListTab(QWidget *parent) :
     m_contextMenu(new QMenu(this)),
     m_deleteAction(m_contextMenu->addAction(tr("Delete"), this, SLOT(deleteAlbum()))),
     m_newAlbumAction(new QAction(tr("New album"), this)),
-    m_noResultsLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No albums found")), this)),
+    m_noResultsLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No albums found")), this)),
     m_grid(new QGridLayout(this))
 {
     this->addAction(m_newAlbumAction);
