@@ -16,7 +16,7 @@ class YouTubeMyChannelWindow : public StackedWindow
     Q_OBJECT
 
 public:
-    explicit YouTubeMyChannelWindow(Session *session, QWidget *parent);
+    explicit YouTubeMyChannelWindow(QWidget *parent);
 
 private:
     void clearMenuActions();
